@@ -65,6 +65,10 @@ class Entity():
         if value.initialized:
             raise ComponentAlreadyHaveEntity(value)
 
+        old_component = self._components.pop(key, None)
+        if old_component is not None:
+            old_component.destroy()
+
         self._components[key] = value
         value.create(self)
 
@@ -88,6 +92,10 @@ class Entity():
             if value.initialized:
                 raise ComponentAlreadyHaveEntity(value)
 
+            old_component = self._components.pop(key, None)
+            if old_component is not None:
+                old_component.destroy()
+
             self._components[key] = value
             value.create(self)
 
